@@ -129,7 +129,7 @@ class StubsGenerator(object):
     @staticmethod
     def fully_qualified_name(klass):
         module_name = klass.__module__ if hasattr(klass,'__module__') else None
-        class_name = klass.__name__
+        class_name = klass.__qualname__
 
         if module_name == "builtins":
             return class_name
@@ -176,7 +176,8 @@ class StubsGenerator(object):
                 sig.args = StubsGenerator.apply_classname_replacements(sig.args)
                 sig.rtype = StubsGenerator.apply_classname_replacements(sig.rtype)
 
-            return list(set(signatures))
+            return sorted(list(set(signatures)),
+                          key=lambda fs: fs.args)
         except AttributeError:
             return []
 
@@ -455,7 +456,7 @@ class ClassStubsGenerator(StubsGenerator):
         for name, member in inspect.getmembers(self.klass):
             if inspect.isroutine(member):
                 self.methods.append(ClassMemberStubsGenerator(name, member, self.klass.__module__))
-            elif inspect.isclass(member):
+            elif name != '__class__' and inspect.isclass(member):
                 if member.__name__ not in self.class_name_blacklist:
                     self.classes.append(ClassStubsGenerator(member))
             elif isinstance(member, property):
@@ -633,7 +634,7 @@ class ModuleStubsGenerator(StubsGenerator):
         ]
 
         # import used packages
-        used_modules = self.get_involved_modules_names()
+        used_modules = sorted(self.get_involved_modules_names())
         if used_modules:
             # result.append("if TYPE_CHECKING:")
             # result.extend(map(self.indent, map(lambda m: "import {}".format(m), used_modules)))
